@@ -12,10 +12,13 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
-"""Calls the module entry point."""
+"""Run the app"""
+
 import sys
 
-from . import entry_point
+from .app import App
 
 if __name__ == '__main__':
-    sys.exit(entry_point.entry_point())
+    app = App()
+    result = app.run()
+    sys.exit(result)
